.. Orquestra Core documentation master file, created by
   sphinx-quickstart on Tue May 17 08:33:32 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Orquestra Core
==============

.. toctree::
   :maxdepth: 2
   :hidden:

   tutorials/index
   guides/index

Orquestra\ :sup:`®` Core is a Python library for developing quantum applications. It provides a compatibility layer across quantum computing frameworks and hardware, as well as building blocks used in many near-term quantum and quantum-inspired algorithms. It is part of `Orquestra <https://www.zapatacomputing.com/orquestra-platform/>`_, Zapata's computational workflow platform for quantum computing.

.. button-ref:: tutorials/beginner_tutorial
   :color: primary
   :shadow:

    Get started with Orquestra Core

Featured tutorials
------------------

.. grid:: 2
   :gutter: 3 3 4 5

   .. grid-item-card:: Solve MaxCut with QAOA
      :link: tutorials/basic_qaoa
      :link-type: doc
      
      An end-to-end example of using Quantum Approximate Optimization Algorithm (QAOA) to solve the maximum cut problem.
      

   .. grid-item-card:: Integrations, Modules, and Libraries
      :link: tutorials/integrations
      :link-type: doc

      Explore ansatzes, quantum backends, noise models, optimizers, and graph problems.
